package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````Z)T``#0````(VP```@0`!30`(``(
M`"@`'0`<``$``'`LUP``+%<!`"Q7`0`(````"`````0````$````!@```#0`
M```T@```-(`````!`````0``!0````0````#````-`$``#2!```T@0``&0``
M`!D````$`````0````$``````````(````"````XUP``.-<```4`````@```
M`0```#C7```XUP$`.-<!`&`"``",$@``!@````"````"````1-<``$37`0!$
MUP$`(`$``"`!```&````!`````0```!0`0``4($``%"!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!`````O;&EB+VQD
M+6QI;G5X+6%R;6AF+G-O+C,`````!````!`````!````1TY5```````"````
M!@```"`````$````%`````,```!'3E4`.=G/!88B7]\8@H\BUY0L5B(6H&5A
M````;P````````````````````\``````````````$L`````````8P```"0`
M``!<`````````",````(````5P`````````T````70```&P````<````*@``
M`!H```!H````!@``````````````$````#`````@```````````````2````
M!0```$@````8`````````&8````Y````60```$P`````````9``````````M
M````$0```!T````-```````````````V````7@```"L```!@````````````
M``!#````.`````L```!K``````````````!'`````````#P`````````````
M````````````7P```"P````3````/P```"<```!6```````````````Q````
M`P```#H```!/````20```$$```!G````4P```&T````````````````````S
M````/@`````````A````4@```"4```!4````80```"8`````````````````
M```>`````````#4```!-`````````````````````````"(`````````.P``
M`&X````````````````````````````````````````````````````"````
M6P```#<`````````#````````````````````&D`````````+P````````!*
M```````````````5`````````$```````````````#(`````````!```````
M``!%`````````````````````````!<```````````````$```!5````:@``
M`!8````9````40`````````'``````````````````````````````!8````
M8@```!\````]````1@``````````````"@````````!$````&P````````!0
M````````````````````"0```"X`````````6@`````````4````````````
M```H```````````````.````*0```````````````````$X`````````0@``
M`````````````````&4```````````````````!A````!0```"`````*````
MH!(`"`)$$2$``D``5@!P&,((`#`(`!41```0`@`H`````````$@"8`H`"@`$
MA`.H0`A%8&D`A`D^0CR7``$`""18@`0)8`R3>`!`6@!``$```0$#"0!`@(S`
MA```$)`0BPD`"`$0@(%`0,()@"Q`F`)!`"``(`0)@)0!I`Z74D`%````````
M``8````'````"0`````````````````````````*````#`````X````0````
M$0```!(````4````%P`````````9```````````````:````'@```"``````
M````)````"4````F`````````"<````H````*P`````````M````````````
M```N````+P```#`````Q`````````#4````V`````````#H`````````````
M`#L````]````/@`````````_````0````$(```!$````1P````````!*````
M2P```$P```!-`````````$X```````````````````````````````````!/
M````4`````````!2`````````%0```!7````6````````````````````%D`
M``!:````7@````````!@`````````&$`````````8P```&0`````````````
M`&8```!G````:````&D```!L````7Y:3'*-:[Y!6VY,<PXZ'_PTZEPO2402$
M@72"#7KP2FM]08[%=E0\E,T_#*_W(\X@B0=PT]1DU'PA=+`"+DX]]F:OS&;;
M]P!>!J2'_P&O-.BQ2)WGX*<""LY*KO\^^?^\S]Y'+>)'Q@$Y0`RO;'.%Q>P_
MD`+&#N`]/WZ6?,6)!9!AF.\2`2/YI)V[DQQ\[1$/AOF<@4-%U>RZE9,<6YH[
M#T%-G7RGW:-K6>^7>3GRBQP,%.*>H@+V&=K-XYX%,J6%^Z%L8#)BV^WJT^\.
MR#E`'[F-\0[I^\/"[-Z3'`N*$%>M2^/`V7%8'"O0X2(L#K%S&Y_6O5@[0!_#
MY3\LF"+4:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(WX4@3U>D
MFY;%N9Q`,+B"#5$;?5^R`8MOO]I7&W9OXW"\T$M]F4+NH6L)0]8A8F0'"P^U
MI7ZIG)MBT/J"["SVBVM_FGS0GRS\A_"6?.\+4?F0=8(-0V9+$`5LLLT6ZEKQ
M/:TY#:/@^TE7DEI2_=+O#RS?_DANQ=\??9`0Z2[%F[;(U;)QWZO*GP``````
M```````````````1```````````````@````(```````````````(````.(!
M`````````````"````#^`0`````````````@````@@,``(";````````$@``
M`&0"``"0F@```````!(````+`P``,)H````````2````[P(``/":````````
M$@```+\$``"(V0$``````"``&`"N`0``O)@````````2````Z`(``'2;````
M````$@```)X!``"LF0```````!(```#B!```L/8``#@````2``X`[`,``)C9
M`0``````$``9`)H"```XFP```````!(```#-`@``Z)D````````2````*@4`
M`)39`0`$````$0`8`$$$``"0\@``J`,``!(`#@`R`P``8)H````````2````
MB0,``,B8````````$@```'L$``!0Y```'`$``!(`#@"K`@``5)H````````2
M````0P,``%B9````````$@```/L#``#$Z0$``````!``&0#9````%)L`````
M```2````900``)3A``#$````$@`.`)D$````F@```````!(```!A`P``;)H`
M```````2````_@0``(#H```0"@``$@`.`"0$```HY```*````!(`#@"T`@``
M[)@````````2````'P,``"";````````$@```'<!``!$FP```````!(```#:
M`@``4)L````````2````C0(``(R;````````$@```)P#``"<V0$`!````"$`
M&0!,`@``&)H````````2````4P(``)B;````````$@```/T"``#<F0``````
M`!(```#B`@``I)@````````2````:````+B9````````$@```-D#``"8V0$`
M`````!``&`!:`P``^)@````````2````1@(``#R:````````$@```&P"``!\
MF0```````!(```"=`P``G-D!``0````A`!D`!@0``,3I`0``````$``9`#P#
M``"HV0$`!````!$`&0`Q!```9/<```0````2``X`4`$``!R9````````$@``
M`-($````]P``9````!(`#@""`0``2)H````````2````"P4``)CG``#H````
M$@`.`,,$``#HG0```````!(`#@`[!```:/<````````2``\`O`(``*B:````
M````$@```,P$``!LF````````!(`#`"(````Y)H````````2````]@(``+2:
M````````$@```,P```"LV0$``0```!$`&0"N!```</<```0````1`!``X`,`
M`)C9`0``````$``9`&D#```LFP```````!(````T````H)D````````2````
M<P,``,R:````````$@```.8```#$F0```````!(```#*!```#.$``#0````2
M``X`&0$``)B8````````$@````X$``#$Z0$``````!``&0`=!0``7.(``,P!
M```2``X`G0```!"9````````$@```'L"``#8F@```````!(```!1````L)L`
M```````2````,@(``(B9````````$@```)`!```DF@```````!(```"K````
MO)L````````2````O0````R:````````$@```/<```"8V0$`!````!$`&0";
M`P``G-D!``0````1`!D`!`,``"B9````````$@```$(!```TF0```````!(`
M``!7!```).<``%P````2``X`^@,``,3I`0``````$``9`"H#``"PF```````
M`!(```!Y````T)D````````2`````@$``'B:````````$@```+T$``"(V0$`
M`````!``&`"Y`P``H-D!``0````1`!D`D@(``*2;````````$@```(<$``"`
MYP``&````!(`#@#,`0``3)D````````2````N0$``/R:````````$@```)8#
M``#(FP``'`(``!(`#@!3`P``0)D````````2````'@$``'"9````````$@``
M`$H#```(FP```````!(````8`P``])D````````2````$@,``,":````````
M$@```*("``!HFP```````!(```![`P``E)D````````2````Q0$``)R:````
M````$@```#0%``!LY0``N`$``!(`#@`C`0``A)H````````2````U`(``(R8
M````````$@```&`!```$F0```````!(```"B!```./8``'@````2``X`0@``
M`%R;````````$@```!,$``!8X@``!````!(`#@`O`0``U)@````````2````
M:0$``&29````````$@````!L:6)P97)L+G-O+C4N,3@`7U]G;6]N7W-T87)T
M7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O
M+C(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)4
M34-L;VYE5&%B;&4`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D
M7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS
M965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S
M<')I;G1F`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H
M<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE
M;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U
M:60`<F5A9&QI;FL`97AE8W9P`'-T<F-H<@!F<')I;G1F`')E861D:7(V-`!M
M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I
M<F]N`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?
M7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER
M;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?
M24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U
M7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'!A<E]M:W1M<&1I
M<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]I;FET7V5N=@!'3$E"0U\R+C0````````````````"``,``@`"``$````"
M`````0`!``(``@`!``$``@`"``$``@`"``$````!``(``@`!``$``@`"````
M`@`"``(``P`#``(``@````$``@`#``,``@`!``(``0````$````!``$``0`"
M``$````"`````0`!``(````"`````0````$``0````(````#````````````
M`@`"`````0`!``(```````$`!``"``$```````$``@`"``(``@`"``(``@`"
M``$````"`````0````$``````````0`!`*4#```0````(````!1I:0T```0`
M004````````!``$`(@(``!`````@````%&EI#0```P!!!0````````$``0!Q
M`@``$``````````4:6D-```"`$$%````````A-D!`!4!``"8V0$`%$X``)S9
M`0`43P``H-D!`!18``"HV0$`%#```*S9`0`4/```<-@!`!9H``!TV`$`%D0`
M`'C8`0`6*```?-@!`!94``"`V`$`%@H``(38`0`6%```B-@!`!9M``",V`$`
M%@$``)#8`0`6'P``E-@!`!8K``"8V`$`%FD``)S8`0`61P``H-@!`!8R``"D
MV`$`%E```*C8`0`640``K-@!`!9>``"PV`$`%EL``+38`0`6%P``N-@!`!9N
M``"\V`$`%E\``,#8`0`6+0``Q-@!`!9*``#(V`$`%F0``,S8`0`60```T-@!
M`!8,``#4V`$`%BD``-C8`0`60@``W-@!`!95``#@V`$`%B<``.38`0`6$```
MZ-@!`!9A``#LV`$`%AL``/#8`0`630``]-@!`!8E``#XV`$`%DL``/S8`0`6
M!P```-D!`!8L```$V0$`%C0```C9`0`6%@``#-D!`!83```0V0$`%AP``!39
M`0`65@``&-D!`!9G```<V0$`%@8``"#9`0`690``)-D!`!8X```HV0$`%CL`
M`"S9`0`68@``,-D!`!9!```TV0$`%D@``#C9`0`6.@``/-D!`!8(``!`V0$`
M%EP``$39`0`68```2-D!`!89``!,V0$`%B```%#9`0`6/P``5-D!`!8/``!8
MV0$`%B$``%S9`0`6(@``8-D!`!9K``!DV0$`%F,``&C9`0`6"P``;-D!`!8%
M``!PV0$`%B,``'39`0`6)@``>-D!`!99``!\V0$`%DD``(#9`0`63```"$`M
MZ6L!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y=P_`0``QH_B$\J,XMS_O.4`QH_B
M$\J,XM3_O.4`QH_B$\J,XLS_O.4`QH_B$\J,XL3_O.4`QH_B$\J,XKS_O.4`
MQH_B$\J,XK3_O.4`QH_B$\J,XJS_O.4`QH_B$\J,XJ3_O.4`QH_B$\J,XIS_
MO.4`QH_B$\J,XI3_O.4`QH_B$\J,XHS_O.4`QH_B$\J,XH3_O.4`QH_B$\J,
MXGS_O.4`QH_B$\J,XG3_O.4`QH_B$\J,XFS_O.4`QH_B$\J,XF3_O.4`QH_B
M$\J,XES_O.4`QH_B$\J,XE3_O.4`QH_B$\J,XDS_O.4`QH_B$\J,XD3_O.4`
MQH_B$\J,XCS_O.4`QH_B$\J,XC3_O.4`QH_B$\J,XBS_O.4`QH_B$\J,XB3_
MO.4`QH_B$\J,XAS_O.4`QH_B$\J,XA3_O.4`QH_B$\J,X@S_O.4`QH_B$\J,
MX@3_O.4`QH_B$\J,XOS^O.4`QH_B$\J,XO3^O.4`QH_B$\J,XNS^O.4`QH_B
M$\J,XN3^O.4`QH_B$\J,XMS^O.4`QH_B$\J,XM3^O.4`QH_B$\J,XLS^O.4`
MQH_B$\J,XL3^O.4`QH_B$\J,XKS^O.4`QH_B$\J,XK3^O.4`QH_B$\J,XJS^
MO.4`QH_B$\J,XJ3^O.4`QH_B$\J,XIS^O.4`QH_B$\J,XI3^O.4`QH_B$\J,
MXHS^O.4`QH_B$\J,XH3^O.4`QH_B$\J,XGS^O.4`QH_B$\J,XG3^O.4`QH_B
M$\J,XFS^O.4`QH_B$\J,XF3^O.4`QH_B$\J,XES^O.4`QH_B$\J,XE3^O.4`
MQH_B$\J,XDS^O.4`QH_B$\J,XD3^O.4`QH_B$\J,XCS^O.4`QH_B$\J,XC3^
MO.4`QH_B$\J,XBS^O.4`QH_B$\J,XB3^O.4`QH_B$\J,XAS^O.4`QH_B$\J,
MXA3^O.4`QH_B$\J,X@S^O.4`QH_B$\J,X@3^O.4`QH_B$\J,XOS]O.4`QH_B
M$\J,XO3]O.4`QH_B$\J,XNS]O.4`QH_B$\J,XN3]O.4`QH_B$\J,XMS]O.4`
MQH_B$\J,XM3]O.4`QH_B$\J,XLS]O.4`QH_B$\J,XL3]O.4`QH_B$\J,XKS]
MO.5P0"WI(-!-XA0`C>40$(WE#""-Y10`C>(0$(WB#""-XMO__^O$$9_EQ`&?
MY0$@H.&Z%@#KO#&?Y0!0T^4``%7CM$&?%0D``!I-___KK"&?Y0``4./H#P+E
M7@``"IA!G^5H___K``"4Y53__^MM5L#E``"4Y5'__^L`,*#A``"4Y1HDT^4"
M((+C&B3#Y4O__^L4,)WE46N?[04P@^)1>Y_MD#H$[F1;N.X&:S7NQVNT[A#Z
M\>X:)-#E`2""XQHDP.5#``#*`P&@X9G__^L0$)WE+#&?Y10@G>4`0)'E).&?
MY1AAG^4$P)/E`0!2XP0PH./T/P;E`%"@X0P!G^400(7H!$!!P@C`A>4,`(7E
M\%\&Y0)!A,`,P(7"`P``V@3@L>4$`%'A!."LY?O__QH-X8+B`,"@XP#`C>4%
M,*#AZ`\6Y0,@@N+$$)_E#L&%Y^C^_^NH,)_E`$!0X@T```KH#Q;E1O__ZQP0
MC>*D`)_E2`\`ZXA0G^4``%#C"0``"N@/%N72_O_K$___ZP0`H.$@T(WB<("]
MZ.@/$^7G_O_K`$"@X>W__^KL#Q7E``!0XP$```HN%@#K\/__ZAP0C>)4`)_E
M,P\`ZP``4./L#P7EZO__"O;__^HU___K`0"@XWC__^L`````````````@/__
M_\]!U)@``+B9``"LV0$`F-D!`*CY`0"0V0$`!/L```C[``!`X0``M/@``%#X
M`````*#A`+"@XP#@H.,$$)WD#2"@X00@+>4$`"WE$,"?Y03`+>4,`)_E##"?
MY:S^_^NB_O_K9/<``,B;````]P``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!
MI_[_ZC`Z`0`@`0``"$`MZ2``G^4@,)_E`S!@X`8`4^,(@+V8%#"?Y0``4^,(
M@+T(,_\OX0B`O>B8V0$`F]D!```````(0"WI*`"?Y2@PG^4#,&#@0S&@X:,_
M@^##$+#A"("]"!0@G^4``%+C"("]"#+_+^$(@+WHF-D!`)C9`0``````$$`M
MZ1A`G^4`,-3E``!3XQ"`O1C;___K`3"@XP`PQ.40@+WHK=D!`"0`G^4(0"WI
M`#"0Y0``4^,#```*%#"?Y0``4^,````*,_\OX0A`O>C:___J0-<!``````#P
M#RWI.,"`X@/<3>)X,(#B@&"-XFP`C>4H8(WE2#"-Y?!'S>$"`9SH_TB@XP``
MH.,AK*#A"*2*X0%4H.$()*#A6%"-Y5R@C>4P((WEV"7-X0!0H.,A9*#A!"`"
MX`$<H.$%,`/@*+R@X0%`@N$#4*#A-+"-Y?!$S>'00\WA_RB@XP`PH.,"0`3@
M`U`%X-`DS>$H=*#A"&R&X60`C>4\`(WE`!"@X_\,H.,&``#@!Q`!X``@@N$!
M,(/A_P"@XP`0H.,*``#@"Q`!X&!PC>4`((+A`3"#X=`&S>$(C*#A"$"$X0"0
MH./_C*#C"```X`D0`>`XL(WE`$"$X0%0A>'8`\WA_X"@XP"0H.,(``#@"1`!
MX`0`@.$H0)WE!1"!X4B0G>4(P(SB\"#$X?@`Q.$)`%SA$$"$XBA`C>6Y__\:
M`*"@XX#`C>(`8.#C`'"@X]@&S.'0),SA@%"-X@C`C.+:@(7A`"`BX`$P(^#8
M`,SA""`BX`DP(^``("+@`3`CX`(`DN"B3Z#A`Q"CX(-`A.&C7Z#A!`"`X040
M@>$(H(KB!@``X`<0`>`"#%KC^`?,X>;__QIL<)WE;+"=Y7`<G^708,?A`XR-
MXFR0G>5L4)WE\&+-X="BR^'18(CA;!"=Y=B!R>'80,7A\*#-X=`!P>$@P)WE
M^(#-X="`S>'X0<WA)$"=Y?`!S>$P#)_E"&"6X*RMH.&,(J#A"7"GX(2BBN$`
M8);@`!"@X]B!S>'00<WA`J"*X0%PI^#8(,WAV`'-X0I@EN`(@,+A`$`$X`F0
MP^$(0(3A`5`%X!@@G>4`<*?B"5"%X02@EN`<@)WE!;"GX"(!H.'XH\WA"+"@
MX0@/@.'8@\WA*Q&@X0(OH.$`((+A`3"`X0!@X./0`LWA`'"@XP:`".`'D`G@
M`F`&X`-P!^"`RY_E`[R-XOABS>$`8`;@`7`'X-R@B^'X9,WAT&'-X?"CS>&H
M3:#A`"#&X0$PQ^'88,WAT`/-X8BBH.&)0H3A!@"0X`<0H>`*0(3A\`3-X=@$
MS>'09,WA",",X@(`@.$#$('A)"N?Y?`#S>'0H\WA`F"6X``PH.,#<*?@"F"6
MX`MPI^`@L)WE!*"6X"!`G>4K`:#A`+"GX@!PH./PI,WA)+"=Y00OH.$`8.#C
M"P^`X="DS>$`((+A![`+X"1PG>4&H`K@)Q&@X0$P@.$#'(WBJFV@X=P`@>&+
M8H;AJWV@X?@$S>$``.#C`!"@XP(``.`#$`'@V"/-X?`#S>&*0J#A`"`"X`$P
M`^#8!,WA\"7-X=`AS>$"`)#@<"J?Y0,0H>``()+@`#"@XP$PH^#8`LWA^"/-
MX=`ES>$(`,#A"1#!X0`@@N$!,(/A!`"&X080A^'80\WA\`7-X2@!H.%0P)WE
M`D"4X`D/@.$I$:#A""^@X0-0I>``((+A`3"`X0``X.,`$*#C#&"4X`(``.`#
M$`'@`'"EXMA)S>'X`\WA[`F?Y0`0H.,$`)#@!1"AX-!$S>'P!<WAV`/-X?AD
MS>$&@*#A`$`$X`%0!>#0!<WA\$3-X=A"S>$`8.#C!H`(X`!`E.`!4*7@T`/-
MX?A"S>'01,WA!Y"@X0H`P.$`<*#C"Q#!X0>0">`$`(#A!1"!X=A"S>&H;:#A
MB"*@X8EBAN$`0)3@`F"&X2H!H.$+#X#A`5"EX%3)G^4&0)3@*Q&@X0HOH.$!
M,(#A`%"EX@-LC>(`((+A`!"@XP``X.,"``#@`Q`!X/!$S>'<0(;A^`+-X1P)
MG^4`$*#C!`"0X`40H>#81,WA\`7-X=@"S>'0I,WA`&#@XP!`!.`!4`7@T`7-
MX?A$S>'00\WA!J`*X`!PH.,`0)3@`5"EX-@#S>'P0\WAV$3-X0@`P.$)$,'A
M![`+X`0`@.$%$('AT$/-X:IMH.&*(J#ABV*&X0!`E.`"8(;A*`&@X0D/@.$!
M4*7@""^@X09`E.`I$:#A`3"`X0!0I>(#;(WB`"""X0C`C.(``.#C`!"@XP(`
M`.`#$`'@^$3-X=Q`AN'P`\WA5`B?Y0`0H.,$`)#@!1"AX-!$S>'P!<WAT`/-
MX=B$S>$`8.#C`$`$X`%0!>#0!<WA\$3-X=A#S>$&@`C@`'"@XP!`E.`!4*7@
MV`+-X?A#S>'01,WA"@#`X0L0P>$'D`G@!`"`X040@>'80\WAJ&V@X8@BH.&)
M8H;A`$"4X`)@AN$J`:#A"P^`X0%0I>`*+Z#A!D"4X"L1H.$!,(#A`%"EX@-L
MC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#P1,WAW$"&X?@#S>&,!Y_E`!"@
MXP0`D.`%$*'@V$3-X?`%S>'8`\WAT*3-X0!@X.,`0`3@`5`%X`:@"N#X1,WA
MT`7-X=A"S>$`<*#C![`+X`!`E.`!4*7@T`/-X?A"S>'81,WA"`#`X0D0P>$$
M`(#A!1"!X=A"S>&J;:#ABB*@X8MBAN$`0)3@`F"&X2@!H.$)#X#A`5"EX`@O
MH.$&0)3@*1&@X0$P@.$`4*7B`VR-X@`@@N$(P(SB``#@XP`0H.,"``#@`Q`!
MX/A$S>'<0(;A^`+-X<0&G^4`$*#C!`"0X`40H>#01,WA\`7-X=@"S>'8A,WA
M`&#@XP!`!.`!4`7@T`7-X?!$S>'00\WA!H`(X`!PH.,`0)3@`5"EX-@#S>'P
M0\WAT$3-X0H`P.$+$,'A!Y`)X`0`@.$%$('AT$/-X:AMH.&((J#AB6*&X0!`
ME.`"8(;A*@&@X0L/@.$!4*7@"B^@X09`E.`K$:#A`3"`X0!0I>(#;(WB`"""
MX0C`C.(``.#C`!"@XP(``.`#$`'@\$3-X=Q`AN'P`\WA_`6?Y0`0H.,$`)#@
M!1"AX-A$S>'P!<WAT`/-X="DS>$`8.#C`$`$X`%0!>#0!<WA^$3-X=A#S>$&
MH`K@`'"@XP!`E.`!4*7@V`+-X?A#S>'81,WA"`#`X0D0P>$'L`O@!`"`X040
M@>'80\WAJFV@X8HBH.&+8H;A`$"4X`)@AN$H`:#A"0^`X0%0I>`(+Z#A!D"4
MX"D1H.$!,(#A`%"EX@-LC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#X1,WA
MW$"&X?@#S>$T!9_E`!"@XP0`D.`%$*'@T$3-X?`%S>'8`\WAV(3-X0!@X.,`
M0`3@`5`%X-`%S>'P1,WAV$+-X0:`".``<*#C`$"4X`%0I>#0`\WA^$+-X=!$
MS>$*`,#A"Q#!X0>0">`$`(#A!1"!X=A"S>&H;:#AB"*@X8EBAN$`0)3@`F"&
MX2H!H.$+#X#A`5"EX`HOH.$&0)3@*Q&@X0$P@.$`4*7B`VR-X@`@@N$(P(SB
M``#@XP`0H.,"``#@`Q`!X/!$S>'<0(;A^`+-X6P$G^4`$*#C!`"0X`40H>#8
M1,WA\`7-X=@"S>'0I,WA`&#@XP!`!.`!4`7@T`7-X?A$S>'00\WA!J`*X`!P
MH.,`0)3@`5"EX-@#S>'P0\WAV$3-X0@`P.$)$,'A![`+X`0`@.$%$('AT$/-
MX:IMH.&*(J#ABV*&X0!`E.`"8(;A*`&@X0D/@.$!4*7@""^@X09`E.`I$:#A
M`3"`X0!0I>(#;(WB`"""X0C`C.(``.#C`!"@XP(``.`#$`'@^$3-X=Q`AN'P
M`\WAI`.?Y0`0H.,$`)#@!1"AX-!$S>'P!<WAT`/-X=B$S>$`8.#C`$`$X`%0
M!>`&@`C@\$3-X=`%S>'80\WA`'"@XP>0">``0)3@`5"EX-@"S>'X0\WAT$3-
MX0H`P.$+$,'A!`"`X040@>'80\WAJ&V@X8@BH.&)8H;A`$"4X`)@AN$J`:#A
M"P^`X0%0I>`*+Z#A!D"4X"L1H.$!,(#A`%"EX@-LC>(`((+A",",X@``X.,`
M$*#C`@``X`,0`>#P1,WAW$"&X?@#S>'<`I_E`!"@XP0`D.`%$*'@V$3-X?`%
MS>'8`\WAT*3-X0!@X.,`0`3@`5`%X-`%S>'X1,WAV$+-X0:@"N``<*#C`$"4
MX`%0I>#0`\WA^$+-X=A$S>$(`,#A"1#!X0>P"^`$`(#A!1"!X=A"S>&J;:#A
MBB*@X8MBAN$`0)3@`F"&X2@!H.$)#X#A`5"EX`@OH.$&0)3@*1&@X0$P@.$`
M4*7B`VR-X@`@@N$(P(SB``#@XP`0H.,"``#@`Q`!X/A$S>'<0(;A^`+-X10"
MG^4`$*#C!`"0X`40H>#01,WA\`7-X=@"S>'8A,WA`&#@XP!`!.`!4`7@T`7-
MX?!$S>'00\WA!H`(X`!PH.,`0)3@`5"EX-@#S>'P0\WAT$3-X0H`P.$+$,'A
M!Y`)X`0`@.$%$('AT$/-X:AMH.&((J#AB6*&X0!`E.`"8(;A*@&@X0L/@.$!
M4*7@"B^@X09`E.`K$:#A`3"`X0!0I>(#;(WB`"""X0C`C.(``.#C`!"@XP(`
M`.`#$`'@\$3-X=Q`AN'P`\WA3`&?Y0`0H.,$`)#@!1"AX-A$S>'P!<WAT`/-
MX="DS>$`8.#C`$`$X`%0!>#0!<WA^$3-X=A#S>$&H`K@`'"@XP!`E.`!4*7@
MV`+-X?A#S>'81,WA"`#`X0D0P>$'L`O@!`"`X040@>'80\WAJFV@X8HBH.&+
M8H;A`$"4X`)@AN$H`:#A"0^`X0%0I>`(+Z#A!D"4X"D1H.$!,(#A`%"EX@-L
MC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#X1,WAW$"&X?@#S>&$`)_E`!"@
MXP0`D.`%$*'@T$3-X?`%S>'8`\WAV(3-X0!@X.,`0`3@`5`%X-`%S>'P1,WA
MV$+-X0:`".``<*#C`$"4X`%0I>#0`\WA^$+-X=!$S>$*`,#A"Q#!X0>0">`$
M`(#A!1"!X=A"S>&H;:#AB"*@X8EBAN$`0)3@#P``ZH#]__^(_?__H/W__YEY
M@EHP_O__2/[__U#^__]8_O__8/[__VC^__]P_O__>/[__X#^__^(_O__D/[_
M_Z'KV6X"8(;A*@&@X0L/@.$!4*7@"B^@X09`E.`K$:#A`3"`X0!0I>(#;(WB
M`"""X0C`C.(``.#C`!"@XP(``.`#$`'@\$3-X=Q`AN'X`LWAB``?Y0`0H.,$
M`)#@!1"AX-A$S>'P!<WAV`+-X="DS>$`8.#C`$`$X`%0!>`&H`K@^$3-X=`%
MS>'00\WA`'"@XP>P"^``0)3@`5"EX-@#S>'P0\WAV$3-X0@`P.$)$,'A!`"`
MX040@>'00\WAJFV@X8HBH.&+8H;A`$"4X`)@AN$H`:#A"0^`X0%0I>`(+Z#A
M!D"4X"D1H.$!,(#A`%"EX@-LC>(`((+A",",X@``X.,`$*#C`@``X`,0`>#X
M1,WAW$"&X?`#S>%0`1_E`!"@XP0`D.`%$*'@T$3-X?`%S>'0`\WAV(3-X0!@
MX.,`0`3@`5`%X-`%S>'P1,WAV$/-X0:`".``<*#C`$"4X`%0I>#8`LWA^$/-
MX=!$S>$*`,#A"Q#!X0>0">`$`(#A!1"!X=A#S>&H;:#AB"*@X8EBAN$`0)3@
M`F"&X0%0I>`&0)3@`%"EX@-LC>((P(SB*@&@X0L/@.$K$:#A"B^@X?!$S>$!
M,(#AW$"&X0`@@N$``.#C`@``X`PB'^4`$*#C!""2X`,0`>``,*#C!3"CX/@#
MS>'81,WA\"7-X=@CS>'0I,WA`&#@XP)`!.`#4`7@V"+-X?A%S>'01<WA!J`*
MX`!PH.,"0)3@`U"EX-@ES>'X1,WAT$/-X0>P"^"J;:#A"$#$X0E0Q>$$((+A
M!3"#X=A$S>&*`J#ABV*&X0)`E.`#4*7@`&"&X?A"S>'8(LWA",",XBA!H.$&
M()+@`#"CX@E/A.'X),WA`SR-XBE1H.'<8(/AV"3-X0@/H.$`D*#C`(#@XP@@
M`N`),`/@`("$X020A>'H0A_E\(7-X09`E.``4*#C!U"EX-!ES>'X1<WA`$#@
MXP!0H.,$8`;@!7`'X-!$S>'X9\WAHHV@X09`!.`'4`7@T&/-X?A"S>'81<WA
M@@*@X8."B.$$8);@!7"GX-A#S>'P8\WAV&+-X0I`Q.$+4,7A!D"$X0=0A>'0
M8\WA`("(X0C`C.($8);@!7"GX`@`EN``$*?B`WR-XBI!H.'<8(?A\`3-X0M/
MA.$K4:#A"@^@X?!CS>$`H(3AT&3-X02PA>$`@.#C^*+-X0"0H.,(8`;@T`7-
MX0EP!^#8@LWAT$/-X::MH.$`@"C@H`,?Y0&0*>``0)3@`!"@XP%0I>#8!,WA
MAZ**X0@`(.`)$"'@V(/-X?@$S>%(P)WE"$"4X`E0I>`,@)3@`)"EXH8"H.'P
M@\WA`("*X=`#S>$B0:#A`T^$X0@`D.``$*'B`HR-XO@$S>$C4:#A`@^@X=@D
MS>'8K4CA`)"@XP"`X.,((`+@"3`#X`"`A.$$D(7AHDV@X?"#S>'8`LWA@T*$
MX6S$'^4`@"C@2`0?Y0&0*>``H)K@`!"@XP&PJ^#0!,WA)U&@X0@`(.`)$"'@
MV(?-X?@#S>&"`J#A"*":X`FPJ^`XD)WE`("$X0F@FN``L*OB"`":X``0J^(#
MC(WB\`3-X=R@B.'0A,WA)D&@X0=/A.$&#Z#A`'"@XP!@X.,&@`C@!Y`)X`!@
MA.$$<(7A!@"@X?ACS>$'$*#AT&/-X:A-H.&)0H3A!@`@X.AD'^4'$"'@"F"6
MX`!PH.,+<*?@V*3-X2-1H.$`H"K@`;`KX(@"H.'XI,WA*+"=Y4C`G>4+8);@
M`'"GX@R@EN``8(3A`+"GX@8`FN``$*OB`FR-XO@$S>'8K$;AV&3-X2)!H.$#
M3X3A`@^@X0`PH.,`(.#C`F`&X`-P!^``((3A!#"%X=A#S>'X(LWAI@V@X00@
M(N!\11_E!3`CX`I`E.``4*#C"U"EX-"DS>&'`H#A`J`JX`.P*^"&(J#A\*3-
MX3"PG>5`P)WE"T"4X`!0I>(,H)3@`D"`X0"PI>($`)K@`!"KX@*LC>+P!,WA
M*`&@X0D/@.$I$:#A""^@X="$S>'03$KA`+"@XP"@X.,*@`C@"Y`)X`*@@.$`
ML('AV"+-X?"CS>'0`\WA.,"=Y:BMH.$"`"#@'"8?Y0,0(>`"0)3@`#"@XP-0
MI>#8),WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@
MX?@#S>$"0(KAV*/-X9#&'^4F`:#A!*":X`"PJ^('#X#A^*3-X2<1H.$#O(WB
M!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AT"/-X?BCS>'8
M`\WA*,"=Y::MH.$"`"#@Q"8?Y0,0(>`"0)3@`#"@XP-0I>#0),WAAZ**X0`@
M(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?@"S>$"0(KAV*+-
MX33''^4H`:#A!*":X`"PJ^()#X#A\*3-X2D1H.$#O(WB""^@X="$S>'<0(OA
M`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AV"/-X?BBS>'8`LWA,,"=Y:BMH.$"
M`"#@;"<?Y0,0(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/`E
MS>%00)WE`!"EX@0`D.``$*'BB"*@X?`#S>$"0(KAT*/-X=C''^4F`:#A!*":
MX`"PJ^('#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@
M"W`'X`*@@.$`L('AV"+-X?"CS>'0`\WA.,"=Y::MH.$"`"#@%"@?Y0,0(>`"
M0)3@`#"@XP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`
MD.``$*'BAB*@X?@#S>$"0(KAV*/-X7S('^4H`:#A!*":X`"PJ^()#X#A\*3-
MX2D1H.$#O(WB""^@X="$S>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('A
MT"/-X?BCS>'8`\WA*,"=Y:BMH.$"`"#@O"@?Y0,0(>`"0)3@`#"@XP-0I>#8
M),WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@X?@"
MS>$"0(KAV*+-X2#)'^4F`:#A!*":X`"PJ^('#X#A^*3-X2<1H.$#O(WB!B^@
MX=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AV"/-X?BBS>'8`LWA
M,,"=Y::MH.$"`"#@9"D?Y0,0(>`"0)3@`#"@XP-0I>#0),WAAZ**X0`@(N`!
M,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?`#S>$"0(KAT*/-X<3)
M'^4H`:#A!*":X`"PJ^()#X#A\*3-X2D1H.$#O(WB""^@X="$S>'<0(OA`*#@
MXP"PH.,*@`C@"Y`)X`*@@.$`L('AV"+-X?"CS>'0`\WA.,"=Y:BMH.$"`"#@
M#"H?Y0,0(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/`ES>%0
M0)WE`!"EX@0`D.``$*'BB"*@X?@#S>$"0(KAV*/-X6C*'^4F`:#A!*":X`"P
MJ^('#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'
MX`*@@.$`L('AT"/-X?BCS>'8`\WA*,"=Y::MH.$"`"#@M"H?Y0,0(>`"0)3@
M`#"@XP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``
M$*'BAB*@X?@"S>$"0(KAV*+-X0S+'^4H`:#A!*":X`"PJ^()#X#A\*3-X2D1
MH.$#O(WB""^@X="$S>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AV"/-
MX?BBS>'8`LWA,,"=Y:BMH.$"`"#@7"L?Y0,0(>`"0)3@`#"@XP-0I>#8),WA
MB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BB"*@X?`#S>$"
M0(KAT*/-X;#+'^4F`:#A!*":X`"PJ^('#X#A^*3-X2<1H.$#O(WB!B^@X=AD
MS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AV"+-X?"CS>'0`\WA.,"=
MY::MH.$"`"#@!"P?Y0,0(>`"0)3@`#"@XP-0I>#0),WAAZ**X0`@(N`!,"/@
M#`"4X/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?@#S>$"0(KAV*/-X53,'^4H
M`:#A!*":X`"PJ^()#X#A\*3-X2D1H.$#O(WB""^@X="$S>'<0(OA`*#@XP"P
MH.,*@`C@"Y`)X`*@@.$`L('AT"/-X?BCS>'8`\WA*,"=Y:BMH.$"`"#@K"P?
MY0,0(>`"0)3@`#"@XP-0I>#8),WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE
M`!"EX@0`D.``$*'BB"*@X?@"S>$"0(KAV*+-X=3,G^4F`:#A!*":X`"PJ^('
M#X#A^*3-X2<1H.$#O(WB!B^@X=ADS>'<0(OA`*#@XP"PH.,*8`;@"W`'X`*@
M@.$`L('AV"/-X?BBS>'8`LWA,,"=Y::MH.$"`"#@?"R?Y0,0(>`"0)3@`#"@
MXP-0I>#0),WAAZ**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"EX@0`D.``$*'B
MAB*@X?`#S>$"0(KAT*/-X33,G^4H`:#A!*":X`"PJ^()#X#A\*7-X2D1H.$#
MO(WB""^@X="%S>'<0(OA`*#@XP"PH.,*@`C@"Y`)X`*@@.$`L('AV"+-X?"C
MS>'0`\WA.,"=Y:BMH.$"`"#@U"N?Y0,0(>`"0)3@`#"@XP-0I>#8),WAB:**
MX0`@(N`!,"/@#`"4X/@DS>%(0)WE`!"EX@0`D.``$*'BB"*@X?@#S>$"0(KA
MV*/-X9#+G^4F`:#A!*":X`"PJ^('#X#A^*/-X2<1H.$#O(WB!B^@X=ACS>'<
M0(OA`*#@XP"PH.,*8`;@"W`'X`*@@.$`L('AT"/-X?"DS>'0!,WA*,"=Y::M
MH.$"`"#@+"N?Y0,0(>`"0)3@`#"@XP-0I>#0)<WAAZ**X0`@(N`!,"/@#`"4
MX/`ES>%00)WE`!"EX@0`D.``$*'BAB*@X?@"S>$"0(KAV*+-X>S*G^4H`:#A
M!*":X`"PJ^()#X#A^*+-X2D1H.$#O(WB""^@X=B"S>'<0(OA`*#@XP"PH.,*
M@`C@"Y`)X`*@@.$`L('AT"3-X?BDS>'8!,WA,,"=Y:BMH.$"`"#@A"J?Y0,0
M(>`"0)3@`#"@XP-0I>#8(\WAB:**X0`@(N`!,"/@#`"4X/`ES>%00)WE`!"E
MX@0`D.``$*'BB"*@X?`#S>$"0(KAT*/-X4C*G^4F`:#A!*":X`"PJ^(#3(WB
M\*/-X=R@A.'00\WA!P^`X2<1H.$&+Z#A`'"@XP!@X.,&0`3@!U`%X`)@@.$`
M<('A!B"@X?ACS>'89,WA`'"@XT#`G>4&("+@W&F?Y:0-H.$*8);@"W"GX-BB
MS>'P9<WAA0*`X0H@(N#0I<WAA&*@X0!@AN$,H)K@`+"KXKS)G^7XHLWAV*+-
MX0-\C>("H)K@`+"KX@@OH.'XHLWAV`+-X2BAH.$)KXKA!@"0X-Q@A^$IL:#A
M`!"AXO!ES>$"8(KA"G"+X=BCS>'0(\WA\`3-X0"`H.$!D*#A``#@XP`0H.,`
M@`C@`9`)X`H`AN$+$(?A`"`"X`$P`^#X8LWA\"/-X08@H.$',*#AV&/-X4P)
MG^4`$*#C!B`"X`<P`^#09<WA2,"=Y:BMH.$`8);@`7"GX-`#S>&)HHKA`@"`
MX0,0@>&((J#A\`7-X0P`EN!08)WE`!"GX@8`D.``$*'B`F"*X?`#S>'0H\WA
MU,B?Y20!H.$&H)K@!0^`X241H.$#7(WB`+"KX@0OH.'<0(7A^*3-X0I@H.$+
M<*#A`*#@XP"PH.,*8`;@"W`'X-BBS>'P1<WA`D"`X=`DS>$`4('A"Q"%X0H`
MA.$`(`+@`3`#X/!#S>'P),WA!""@X04PH.'80LWA>`B?Y0`0H.,$(`+@!3`#
MX-!%S>$XP)WEIJV@X0!`E.`!4*7@T`3-X8>BBN$"`(#A`Q"!X88BH.'P!<WA
M#`"4X%!`G>4`$*7B!`"0X``0H>("0(KA^`/-X=BCS>$$R)_E`UR-X@2@FN``
ML*OB*`&@X?"DS>'<0(7A"0^`X2D1H.$(+Z#A"Y"@X0J`H.$`L*#C`*#@XPJ`
M".`+D`G@T*/-X?!%S>$"0(#AV"3-X0!0@>$+$(7A"@"$X0`@`N`!,`/@^$/-
MX?@DS>$$(*#A!3"@X=!#S>&D!Y_E`!"@XP0@`N`%,`/@T$7-X2C`G>6HK:#A
M`$"4X`%0I>#8!,WAB:**X0(`@.$#$('AB"*@X?`%S>$,`)3@4$"=Y0`0I>($
M`)#@`!"AX@)`BN'X`LWAV*+-X33'G^4#7(WB!*":X`"PJ^+<0(7A)@&@X?BD
MS>$'#X#A)Q&@X08OH.$+<*#A"F"@X0"PH.,`H.#C"F`&X`MP!^#8H\WA\$7-
MX0)`@.'0),WA`%"!X0L0A>$*`(3A`"`"X`$P`^#X0LWA\"3-X00@H.$%,*#A
MV$/-X=`&G^4`$*#C!"`"X`4P`^#01<WA,,"=Y::MH.$`0)3@`5"EX-`$S>&'
MHHKA`@"`X0,0@>&&(J#A\`7-X0P`E.!00)WE`!"EX@0`D.``$*'B`D"*X?`#
MS>'0H\WA9,:?Y0-<C>($H)K@`+"KXMQ`A>$H`:#A\*3-X0D/@.$I$:#A""^@
MX0N0H.$*@*#A`+"@XP"@X.,*@`C@"Y`)X-BBS>'P1<WA`D"`X=@DS>$`4('A
M"Q"%X0H`A.$`(`+@`3`#X/!#S>'X),WA!""@X04PH.'80LWA_`6?Y0`0H.,$
M(`+@!3`#X-!%S>$XP)WEJ*V@X0!`E.`!4*7@V`3-X8FBBN$"`(#A`Q"!X8@B
MH.'P!<WA#`"4X%!`G>4`$*7B!`"0X``0H>("0(KA^`/-X=BCS>&4Q9_E`UR-
MX@2@FN``L*OBW$"%X28!H.'XI,WA!P^`X2<1H.$&+Z#A"W"@X0I@H.$`L*#C
M`*#@XPI@!N`+<`?@T*/-X?!%S>$"0(#AT"3-X0!0@>$+$(7A"@"$X0`@`N`!
M,`/@^$/-X?`DS>$$(*#A!3"@X=!#S>$H!9_E`!"@XP0@`N`%,`/@T$7-X2C`
MG>6FK:#A`$"4X`%0I>#0!,WAAZ**X0(`@.$#$('AAB*@X?`%S>$,`)3@4$"=
MY0`0I>($`)#@`!"AX@)`BN'X`LWAV*+-X<3$G^4#7(WB!*":X`"PJ^+<0(7A
M*`&@X?"DS>$)#X#A*1&@X0@OH.$+D*#A"H"@X0"PH.,`H.#C"H`(X`N0">#8
MH\WA\$7-X0)`@.'8),WA`%"!X0L0A>$*`(3A`"`"X`$P`^#X0LWA^"3-X00@
MH.$%,*#AV$/-X50$G^4`$*#C!"`"X`4P`^#01<WAJ*V@X8FBBN$`0)3@`5"E
MX-@$S>$"`(#A`Q"!X8@BH.'P!<WA,,"=Y0P`E.!00)WE`!"EX@0`D.``$*'B
M`D"*X?`#S>'0H\WA],.?Y0-<C>($H)K@`+"KXMQ`A>$F`:#A^*3-X0</@.$G
M$:#A!B^@X0MPH.$*8*#A`+"@XP"@X.,*8`;@"W`'X-BBS>'P1<WA`D"`X0!0
M@>'0!,WA\$/-X0I`A.$+4(7A!```X`40`>"00Y_E^`7-X=`#S>$`4*#C.,"=
MY0H``.#0I<WAIBV@X8<B@N$*0)3@"U"EX(:BH.'P1,WAV$7-X0*@BN$I$:#A
M!`"`X=!$S>$(+Z#A`+"@XPQ`E.``4*7B`$"4X`!0I>(*0)3@`%"EXB@!H.'P
M1,WA_\#@XP-<C>()#X#AT(3-X=Q`A>$`H.#C"H`(X`N0">#0H\WA\$7-X0)`
M@.$`4('AV"3-X?A#S>$*0(3A`D`$X-@CS>$HP)WEJ`V@X0H@`N`+,`/@S**?
MY?@DS>'0)<WA`+"@XXD"@.$"H)K@`["KX/"ES>'0)<WAV*3-X0"PH.,,()+@
M"D"$X0`PH^($()+@`#"CXHBBH.'X(LWAV$+-X0"@BN$F(:#A"D"4X`!0I>(`
MH.#C^$3-X0<O@N$G,:#A!@^@X0MP!>`*8`3@V*/-X0!`@N$"4(/AT"3-X?A"
MS>$*0(3A"U"%X00@`N#8HLWA!3`#X-A#S>'P),WAI@V@X06P"^`"7(WB!*`*
MX-@@Q>$00I_E`%"@XP0@DN`%,*/@T$3-X8<"@.$*0(3A"U"%X8:BH.'P1,WA
M,%"=Y4#`G>4%()+@`#"CX@"@BN$,0)+@*"&@X0DO@N$`4*/B"`^@X0I`E.``
M4*7B`*""X2DQH.'8`LWA`K"#X=@DS>'P1,WA!("@X060H.$`0.#C`%"@XP2`
M".`%D`G@`$"*X0%0B^$$(`+@!3`#X-A"S>'PH\WA^"3-X06P"^`"7(WB!*`*
MX-`AQ>%<09_E`%"@XP0@DN`%,*/@V$3-X:@-H.&)`H#A"D"$X0M0A>&(HJ#A
M^$3-X3A0G>5(P)WE!2"2X``PH^(`H(KA#$"2X"8AH.$'+X+A`%"CX@8/H.$*
M0)3@`%"EX@"@@N$G,:#AT`/-X0*P@^'0),WA^$3-X01@H.$%<*#A`$#@XP!0
MH.,$8`;@!7`'X`!`BN$!4(OA!"`"X`4P`^#00\WA^*/-X?`DS>$%L`O@`ER-
MX@2@"N#8(<7AI$"?Y0!0H.,$()+@!3"CX-!$S>&F#:#AAP*`X0I`A.$+4(7A
MAJ*@X?!$S>$H4)WE0,"=Y04@DN``,*/B`*"*X0Q`DN``4*/B"D"4X`!0I>(H
M(:#A"2^"X0@/H.'P1,WA`*""X2DQH.'8`\WA`K"#X0\``.J8_O__H>O9;J#^
M__^H_O__L/[__[C^___`_O__R/[__]#^___8_O__X/[__^C^___P_O__^/[_
M_]R\&X_6P6+*V"3-X02`H.$%D*#A`$#@XP!0H.,$@`C@!9`)X`!`BN$!4(OA
M!"`"X`4P`^#80\WA^*+-X?@DS>$%L`O@`ER-X@2@"N#0(L7A6$`?Y0!0H.,$
M()+@!3"CX-A$S>&H#:#AB0*`X0I`A.$+4(7AB**@X?A$S>$P4)WE2,"=Y04@
MDN``,*/B`*"*X0Q`DN`F(:#A!R^"X0!0H^(&#Z#A"D"4X`!0I>(`H(+A)S&@
MX=@"S>$"L(/AT"3-X?A$S>$$8*#A!7"@X0!`X.,`4*#C!&`&X`5P!^``0(KA
M`5"+X00@`N`%,`/@V$+-X?"CS>'P),WA!;`+X`)<C>($H`K@V"+%X1!!'^4`
M4*#C!""2X`4PH^#01,WAI@V@X8<"@.$*0(3A"U"%X8:BH.'P1,WA.%"=Y4#`
MG>4%()+@`#"CX@"@BN$,0)+@*"&@X0DO@N$`4*/B"`^@X0I`E.``4*7B`*""
MX2DQH.'0`\WA`K"#X=@DS>'P1,WA!("@X060H.$`0.#C`%"@XP2`".`%D`G@
M`$"*X0%0B^$$(`+@!3`#X-!#S>'XH\WA^"3-X06P"^`"7(WB!*`*X-`CQ>'(
M01_E`%"@XP0@DN`%,*/@V$3-X:@-H.&)`H#A"D"$X0M0A>&(HJ#A^$3-X2A0
MG>5(P)WE!2"2X``PH^(`H(KA#$"2X"8AH.$'+X+A`%"CX@8/H.$*0)3@)S&@
MX0"@@N$`4*7B`K"#X?A$S>'XHLWAV`/-X=`DS>$$8*#A!7"@X0!`X.,`4*#C
M!&`&X`5P!^``0(KA`5"+X00@`N`%,`/@V$/-X?`DS>&F#:#A!;`+X`)<C>($
MH`K@V"/%X81"'^4`4*#C!""2X`4PH^#01,WAAP*`X0I`A.$+4(7AAJ*@X?!$
MS>$P4)WE0,"=Y04@DN``,*/B`*"*X0Q`DN`H(:#A"2^"X0!0H^((#Z#A"D"4
MX`!0I>(`H(+A*3&@X=@"S>$"L(/AV"3-X?!$S>$$@*#A!9"@X0!`X.,`4*#C
M!(`(X`60">``0(KA`5"+X00@`N`%,`/@V$+-X?"CS>'X),WA!;`+X`)<C>($
MH`K@T"3%X3A#'^4`4*#C!""2X`4PH^#81,WAJ`V@X8D"@.$*0(3A"U"%X8BB
MH.'X1,WA.%"=Y4C`G>4%()+@`#"CX@"@BN$,0)+@)B&@X0<O@N$`4*/B!@^@
MX0I`E.``4*7B`*""X2<QH.'0`\WA`K"#X=`DS>'X1,WA!&"@X05PH.$`0.#C
M`%"@XP1@!N`%<`?@`$"*X0%0B^$$(`+@!3`#X-!#S>'XH\WA\"3-X06P"^`"
M7(WB!*`*X-@DQ>'P0Q_E`%"@XP0@DN`%,*/@T$3-X:8-H.&'`H#A"D"$X0M0
MA>&&HJ#A\$3-X2A0G>5`P)WE!2"2X``PH^(`H(KA#$"2X"@AH.$)+X+A`%"C
MX@@/H.$*0)3@`%"EX@"@@N$I,:#AV`/-X0*P@^'8),WA\$3-X02`H.$%D*#A
M`$#@XP!0H.,$@`C@!9`)X`!`BN$!4(OA!"`"X`4P`^#XHLWA^"3-X=A#S>&H
M#:#AB0*`X06P"^`"7(WB!*`*X-`EQ>&P1!_E`%"@XP0@DN`%,*/@V$3-X0I`
MA.$+4(7AB**@X?A$S>$P4)WE2,"=Y04@DN``,*/B#$"2X"8AH.$'+X+A`*"*
MX08/H.$`4*/B"D"4X"<QH.$`H(+AV`+-X0!0I>("L(/AT"3-X?"CS>'X1,WA
M`*"*X0&PB^$$8*#A!7"@X0!`X.,`4*#C!&`&X`5P!^`*(`+@T$/-X0LP`^#8
MHLWA\"7-X:8-H.$*0`3@"U`%X(<"@.'P1,WA`ER-XFQ%'^78)<7A`%"@X]"D
MS>$$()+@!3"CX-!%S>'X)<WAAB*@X02@BN$%L(OAV$7-X?"DS>$XH)WE0,"=
MY0I`E.``4*7B`"""X0R@E.``L*7B`@":X``0J^(H0:#A\`3-X0E/A.$I4:#A
M"`^@X=`DS>$`H(3A!+"%X0"`X./XH\WA`)"@XP@@`N`),`/@T`/-X=B#S>$"
M'(WB*,"=Y=!&P>$`@"C@#`8?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.B
MBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-
MX29!H.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C
M^*+-X=@#S>$(8`;@"7`'X`(<C>+8@LWAV$;!X0`0H.,`@"C@J`8?Y3#`G>4`
M0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0
MI>((0)3@`%"EX@"`BN'P0\WAT`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-
MX0(/H.$`H(3AT"3-X02PA>$`@.#C\*/-X0@@`N`),`/@V`+-X="#S>$"'(WB
M.,"=Y=!'P>$`@"C@1`<?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"
M`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0\WAV`/-X29!
MH.$'3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*/-
MX0A@!N`)<`?@T`/-X=B#S>$"'(WB*,"=Y=A'P>$`@"C@X`<?Y0`0H.,`0)3@
M`5"EX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((
M0)3@`%"EX@"`BN'X0LWAV`+-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/
MH.$`H(3AT"3-X02PA>$`@.#C^*+-X=@#S>$((`+@"3`#X`(<C>+8@LWAT$C!
MX0`0H.,`@"C@?`@?Y3#`G>4`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A
M!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WAT`/-X29!H.$'
M3X3A"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C\*/-X0A@
M!N`)<`?@V`+-X="#S>$"'(WB.,"=Y=A(P>$`@"C@&`D?Y0`0H.,`0)3@`5"E
MX*:MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@
M`%"EX@"`BN'X0\WAV`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`
MH(3AT"3-X02PA>$`@.#C^*/-X0@@`N`),`/@T`/-X=B#S>$"'(WB*,"=Y=!)
MP>$`@"C@M`D?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`H
MX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-X29!H.$'3X3A
M"`"0X``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*+-X=@#S>$(
M8`;@"7`'X`(<C>+8@LWAV$G!X0`0H.,`@"C@4`H?Y3#`G>4`0)3@`5"EX*:M
MH.'P1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"E
MX@"`BN'P0\WAT`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`H(3A
MT"3-X02PA>$`@.#C\*/-X0@@`N`),`/@V`+-X="#S>$"'(WB.,"=Y=!*P>$`
M@"C@[`H?Y0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%
MS>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0\WAV`/-X29!H.$'3X3A"`"0
MX``0H>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*/-X0A@!N`)<`?@
MT`/-X=B#S>$"'(WB*,"=Y=A*P>$`@"C@B`L?Y0`0H.,`0)3@`5"EX*:MH.'P
M1<WAT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`
MBN'X0LWAV`+-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`H(3AT"3-
MX02PA>$`@.#C^*+-X=@#S>$((`+@"3`#X`(<C>+8@LWAT$O!X0`0H.,`@"C@
M)`P?Y3#`G>4`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`
MD*#C#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WAT`/-X29!H.$'3X3A"`"0X``0
MH>(G4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C\*/-X0A@!N`)<`?@V`+-
MX="#S>$"'(WB.,"=Y=A+P>$`@"C@P`P?Y0`0H.,`0)3@`5"EX*:MH.'P1<WA
MT$3-X8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X
M0\WAV`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`H(3AT"3-X02P
MA>$`@.#C^*/-X0@@`N`),`/@T`/-X=B#S>$"'(WB*,"=Y=!,P>$`@"C@;`6?
MY0`0H.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C
M#$"4X`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-X29!H.$'3X3A"`"0X``0H>(G
M4:#A^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*+-X=@#S>$(8`;@"7`'X`(<
MC>+8@LWAV$S!X0`0H.,`@"C@T`2?Y3#`G>4`0)3@`5"EX*:MH.'P1<WAT$3-
MX8>BBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'P0\WA
MT`/-X2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`H(3AT"3-X02PA>$`
M@.#C\*/-X0@@`N`),`/@V`+-X="#S>$"'(WB.,"=Y=!-P>$`@"C@-`2?Y0`0
MH.,`0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4
MX`!0I>((0)3@`%"EX@"`BN'X0\WAV`/-X29!H.$'3X3A"`"0X``0H>(G4:#A
M^`3-X08/H.$`H(3AV&3-X02PA>$`@.#C^*/-X0A@!N`)<`?@T`/-X=B#S>$"
M'(WB*,"=Y=A-P>$`@"C@F`.?Y0`0H.,`0)3@`5"EX*:MH.'P1<WAT$3-X8>B
MBN&&`J#A!(`HX-!%S>$`D*#C#$"4X`!0I>((0)3@`%"EX@"`BN'X0LWAV`+-
MX2)!H.$#3X3A"`"0X``0H>(C4:#A\`3-X0(/H.$`H(3AT"3-X02PA>$`@.#C
M^*+-X=@#S>$((`+@"3`#X`(<C>+8@LWAT$[!X0`0H.,`@"C@_`*?Y3#`G>4`
M0)3@`5"EX**MH.'P1<WAV$3-X8.BBN&"`J#A!(`HX-!%S>$`D*#C#$"4X`!0
MI>((0)3@`%"EX@"`BN'P0\WAT`/-X29!H.$'3X3A"`"0X``0H>(G4:#A^`3-
MX08/H.$`H(3AV&3-X02PA>$`@.#C\*/-X0A@!N#8`LWA"7`'X`(<C>+0@\WA
MV$[!X0`0H.,`@"C@8`*?Y3C`G>4`0)3@`5"EX*:MH.'P1<WAT$3-X8>BBN&&
M`J#A!(`HX-!%S>$,0)3@`%"EX@A`E.``4*7B`("*X?A#S>'8`\WA`JR-XB)!
MH.$(`)#@`!"AXM"/RN'P!,WAT*3-X0-/A.$C4:#A`@^@X0`PH.,`(.#C`J`*
MX`.P"^``((3A!#"%X0(`H.'X(\WAT"/-X0`PH.,HP)WE`@`@X,`AG^6J3:#A
M"""2X`DPH^#8A,WA#""2X``PH^((`"#@`""2X``PH^*+0H3A^"+-X8J"H.$$
M@(CAV$+-X28!H.$'#X#A"$"4X"<1H.$&+Z#A`%"EX@"`X.,`D*#C"$`$X`E0
M!>`"@(#A`)"!X0!@H.,`<*#C`AR-XOAES>'XA,WAV"_!X:2=H.%8D(WE*L&@
MX3`!G^7X8LWA*,"-Y5APG>4PP)WE`""2X``0H.,!,*/@A7*'X0Q@DN!8<(WE
M`'"CXB@PG>6E+:#A"S^#X?!ES>%<((WE*#"-Y=ADS>'8(\WAA(*@X0H/H.$"
M8";@`W`GX-`DS>$XP)WE`F`FX`-P)^#0)<WA\&/-X3!@G>4&()+@V&7-X0A@
MAN$K@:#A+("-Y=B"S>'0H,WA!B"2X`"`B.'8`<WA#*":X`"PJ^(`0)3@`5"E
MX-@`S>%(8)WE`)"@XP8`D.#08LWA`!"AX@N0">`"8);@T"'-X0!PI^(`L*#C
M"""2X``PH^(`@.#C"H`(X`M0!>``H.#C"Q`!X`MP!^`+,`/@;+"=Y0I`!.`*
M``#@"F`&X`H@`N#P8,OA^$#+X?@!R^'P@LOA\"'+X0/<C>+P#[WH'O\OX=;!
M8LKX0RWI`'!0X@&0H.$K```*L#"?Y0"`D^4``%CC)0``"@!@U^4]`%;C``!6
M$P!@H`,!8*`3$0``&@!`F.4``%3C#```"@A0H.$$`*#A!Q"@X08@H.$@\/_K
M``!0XP(``!H&,-3G/0!3XPP```H$0+7E``!4X_/__QH$`*#A^(.]Z`$PA^(#
M8*#A`2#3Y#T`4N,``%(3^O__&@9@9^#E___J!5!HX`$`AN)%4:#A`%")Y0``
MA.#X@[WH"`"@X?B#O>@'`*#A^(.]Z)S9`0`P0"WI`$"@X5!0G^4,T$WB!`"@
MX000C>+%___K``!0XPP```H$$)WE`""5Y0$Q@N`$P)/E``!<XP'!@N?S__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKM___J#-"-XC"`O>B<V0$`\$\MZ0%`H.$`
M,-'E#-!-X@!@H.$]`%/C`4"!`@0`H.&*[__K!!"-X@!PH.$&`*#AIO__ZP!0
M4.)````*@^__ZP``5^$T``":!("=Y:"1G^4(@:#A`,#6Y3T`7.,``%P3`,"@
M`P'`H!,&```*`3"&X@/`H.$!$-/D/0!1XP``41/Z__\:#,!FX`(`A^(,`(#@
M`%"9Y9WO_^M4,9_E``!0XP@`A>=0```*`""3Y000G>4`,-;E`1&2YP``4^,`
M,,'E"P``"CT`4^,)```*!@"@X0$@@>(!``#J/0!3XP0```H!,/#E`A"@X0``
M4^,!,,+D^/__&@$@H.$],*#C`##!Y0$PU.0``%/C`3#BY?O__QH``*#C#-"-
MXO"/O>@!,-3D``!3XP$PQ>3X__\*`3#4Y```4^,!,,7D]___&O/__^JLD)_E
M`*"9Y0`PFN4``%/C(@``"@HPH.$$(+/E`5"%X@``4N/[__\:`A"%X@$1H.&`
M,)_E`""3Y0``4N,*```*"@"@X8[O_^L``%#C``")Y14```H%@:#A`3"%X@`@
MH.,#(8#G!%"-Y:G__^H!(*#C`0"@X0`@@^54[__K`+!0X@D```H%@:#A"A"@
MX0@@H.%:[__K"P"@X0"PB>7M___J`U"@X0@0H./@___J``#@X\?__^J<V0$`
ML-D!`/!`+>D`0%#B;-!-X@(```H`,-3E``!3XP$``!ILT(WB\("]Z+_N_^L`
M8%#B^O__"@8`H.%:[__K`!!0XA-0@>($`*#A)@``"A,@T>4N`%+C&@``"O[N
M_^L`<*#A!0"@X?ON_^L``(?@`@"`XBCO_^L%,*#AB!"?Y00@H.$`<*#A9>__
MZP<0H.$#`*#C#2"@X1#O_^L!`'#C!P"@X0,```H0,)WE#SH#X@$)4^,2```*
MZN[_ZP<`H.'*[O_KV___ZA0PT>4``%/CV/__"BX`4^/?__\:%3#1Y0``4^/3
M__\*V___Z@8`H.'W[O_K!`"@X1#O_^MLT(WB\("]Z+___^OK___JY/<``'!`
M+>D(09_E``"4Y;GN_^MX,)#E``"4Y010D^6U[O_K96#0Y0``E.6R[O_K?V`&
MX@0PD.6P,=/A@SN@X2-HAN&R8,7A``"4Y:KN_^MX,)#E``"4Y010D^6F[O_K
MM!"?Y0`@H.,&[__K'`"%Y0``E.6@[O_K>#"0Y0``E.4$4)/EG.[_ZQPUD.4`
M`)3E(#"%Y9CN_^MX,)#E``"4Y010D^64[O_K-#&0Y0``4^,#```*``"4Y8_N
M_^LT,9#E<#"3Y20PA>4``)3EBN[_ZP!0H.-X,)#E``"4Y00PD^4H4(/EA.[_
MZW@PD.4``)3E!#"3Y1A0@^5_[O_K>#"0Y0``E.4$0)/E>^[_ZU`RD.4L,(3E
M<("]Z)C9`0``^P``.$`MZ0!0H.%L0)_E``"4Y7'N_^L%$*#A!2V`X@,`H./3
M[O_K``!0XP$```H``*#C.("]Z```E.5G[O_K4#&0Y0\Z`^(!"5/C!0``"@``
ME.5A[O_K4#&0Y0\Z`^(*"E/C\?__&@4`H.$"$*#C7>[_ZP$`<.(``*`S.("]
MZ)C9`0#P0"WI`=I-XL!0G^4,T$WB`LJ-X@`PE>4`8*#A`7"@X:P`G^4$$(WB
MJ""?Y?P_#.6I[O_K``!0XQP``-H!0$#B!#"-X@0@T^<``%+C%0``"@!`H.$$
M`(WB+Q"@XP0@H.&X[O_K``!0XQ````IH,)_E``"3Y3CN_^L&$*#A!""-X@0P
MH.%5[O_K`LJ-XOPO'.4`,)7E`P!2X0L``!H!VHWB#-"-XO"`O>@``%3CZ/__
M&B0PG^4``)/E)^[_ZP80H.$'(*#A#^[_Z^[__^IJ[O_KH-D!`.SW``#_#P``
MF-D!`!PPG^400"WI``"3Y1KN_^L0$)_E$""?Y1`PG^400+WHA.[_ZIC9`0#\
M]P``K)D``!CX```00"WI"-!-XC1`G^4``)3E#.[_Z^S__^L``)3E">[_ZR`P
MG^4`(*#C!""-Y0`PC>44$)_E%""?Y1'N_^L(T(WB$("]Z)C9`0``^P``)/@`
M`)#R``!P0"WI`MI-XJA0G^40T$WB`BJ-X@`PE>4,,(+E3N[_ZY00G^64,)_E
M`""@X00`C>)V[O_K``!0XQD``+H!&HWB!`"-X@@0@>(!*J#C2.[_ZP!`4.(2
M``"Z`0"$XBGN_^L`8%#B$```"@$:C>(($('B!""@X?GM_^L&`*#A`#"@XP0P
MQN<".HWB#""3Y0`PE>4#`%+A!@``&@+:C>(0T(WB<("]Z```H./U___J!@"@
MX?/__^H6[O_KH-D!`#SX``!(^```S?__ZO!/+>D!VDWBF*&?Y1303>("*HWB
M`#":Y0!0H.$!8*#AA`&?Y0@0C>+T/P+E\_W_ZR\0H.,`0*#A!0"@X9;M_^L`
M`%#C"P``"F`!G^4%$*#A-O[_ZP4`H.$".HWB]"\3Y0`PFN4#`%+A30``&@':
MC>(4T(WB\(^]Z`4`H.&_[?_K+!&?Y0"0H.$&`*#A\>W_ZP"P4.+K__\*&'&?
MY1B!G^4889_E`##;Y0``4^,'L*`!``!4XP0```H$`*#A"Q"@X1?N_^L``%#C
M)```"@L`H.&J[?_K`#"+X`$@4^4O`%+C!0``&@`@H.,!(&/E`>!3Y0$`0.(O
M`%[C^O__"@'`@.()P(S@"`!<X<[__\H+(*#AK!"?Y:PPG^4`4(WE#`"-X@CN
M_^L``);E?^W_ZPP0C>(%+8#B`P"@X['M_^L``%#C!0``&@``EN5W[?_K4#&0
MY0\Z`^(""5/C!@``"@``H.-,$)_EN^W_ZP``4.,`L*#AR___&K/__^H,`(WB
M`1"@XVSM_^L``%#C\___&@P0C>(8`)_EY?W_ZPP`C>+:[?_KK/__ZJCM_^N@
MV0$`4/@``%SX``!L^```3/@``/\/``"8V0$`</@``'CX````,-#E``!3XQ[_
M+P$!((#B+P!3XP(`H`$!,-+D``!3X_K__QH>_R_A$$`MZ0!`4.(K```*`##4
MY0``4^,H```*6^W_ZP$`0.(`,(3@`P!4X0L``"H`(-3G+P!2XRD``!H!($/B
M`P``Z@`0TN4!($+B+P!1XR,``!H$`%+A`C"@X?C__QH$`%/A`3!#$@0``!H0
M``#J`!#3Y0$P0^(O`%'C`@``&@,`5.$#(*#A^/__.@(@9.`",(+B`0I3XP\`
M`(H$$*#A`2""XFP`G^7\[/_K9`"?Y1"`O>@`,-/E+P!3XQ(``!H"`*#C8>W_
MZP``4.,"```*+C"@X[`PP.$0@+WH``"@XQ"`O>@!($/B`P``Z@`0TN4!($+B
M+P!1X]C__PH"`%3A`C"@X?C__SK4___J"`"?Y1!`O>B`[?_JM-D!`'CX```P
M0"WI--!-XE#AG^4(P(WB3$&?Y0\`ON@`4)3E#P"LZ`\`ON@L4(WE`.">Y0\`
MK.@P`9_EL.#,X5_]_^LH`9_E7?W_ZR0!G^5;_?_K(`&?Y5G]_^L<`9_E5_W_
MZQ@!G^55_?_K%`&?Y5/]_^L0`9_E4?W_ZPP!G^5/_?_K"`&?Y4W]_^L$`9_E
M2_W_ZP`!G^5)_?_K_`"?Y4?]_^L$$(WB]`"?Y1']_^L`$%#B`0``"M``G^59
M_?_K!!"-XMP`G^4*_?_K`!!0X@$```K0`)_E4OW_ZP00C>+(`)_E`_W_ZP`0
M4.(*```*D`"?Y4O]_^N``)_EL!"?Y4C]_^LL()WE`#"4Y0,`4N$3```:--"-
MXC"`O>@$$(WBD`"?Y?/\_^L`$%#B`@``"E0`G^4[_?_K[O__ZAD`C>)T$)_E
M"B"@XR'M_^L``%#CZ/__&B,0C>(L`)_E,?W_Z^3__^KV[/_K=/<``*#9`0!\
M^```B/@``)#X``"<^```I/@``+3X``!0^```P/@``,SX``#8^```7/@``.3X
M``#P^```_/@``!#Y```D^0``,/D``&#Y``!`^0``5/D``!!`+>D(T$WB1$"?
MY0``E.4!`'#C`0``"@C0C>(0@+WH,`"?Y000C>+"_/_K``!0XP0```H``-#E
M``!0XP$```HP`%#B`0"@$P``A.4(T(WB$("]Z)#9`0#`^```"$`MZ7/L_^N<
M[/_K``!0XP``D!4(@+WH\$$MZ0!PH.',0)_E*-!-X@S`C>(/`+3H#P"LZ`<`
ME.@,0)WE``!4XP<`C.@6```*#%"-X@4``.J6[/_K``!0XQ,```H$0+7E``!4
MXPX```H($(WB!`"@X9G\_^L'$*#A`&!0X@(```H`,-;E``!3X_#__QH$`*#A
M!Q"@X=S\_^L$0+7E``!4X_#__QHHT(WB\(&]Z`<`H.%I[/_K`("@X08`H.%F
M[/_K``"(X`(`@.*3[/_K`&"-Y2`0G^4'(*#A'#"?Y0"`H.'/[/_K!`"@X0@0
MH.'&_/_KV?__ZICW``!P^```;/@``(PYG^7P3RWI`%"@X8'<3>('`)/H--!-
MXCA`C>(,X(/B!P"$Z"1@@^(/`+[H4,"-XD1`C>(/`*SH`P">Z%0IG^4#`(SH
M`#"2Y0<`EN@":8WB+#&&Y0<`A.@T$(WB.`F?Y5W\_^L`0%#B`@``"@`PU.4`
M`%/C_@``&J#__^L`<%#B0$"-`DP```H'`*#A,NS_ZX``H.$!`(#B7^S_ZP`@
MU^4``%+C`$"@X0!@H!$&```*!@"@X>08G^69[/_K`2#WY0)@AN(``%+C^/__
M&M`XG^6!S(WB,,",X@,`G.<``%#C4&"-$@,``!H0``#J!`"VY0``4.,-```*
M-!"-XC;\_^L`<%#B^/__"@`PU^4``%/C]?__"H3]_^L``%#C\O__"@<`H.%O
M[/_K`(!0XBX``!IP.)_E@0R-XC``@.(#8)#G``!6XR<```H`,-;E``!3XP%P
MH!,+```:(@``ZH$<C>(P$('B!S&!X`(Y0^+X8!/E``!6XQL```H`,-;E`7"'
MX@``4^,7```*!@"@X6;]_^L``%#C\/__"@8`H.%1[/_K``!0X^S__PH`@*#A
M#@``ZDSL_^L``%#CJP``&@0`M.4``%#CK@``"C00C>("_/_K`#!0XOC__PH`
M,-/E``!3X_7__PKQ___J`("@XP@`H.'9Z__K`&"@X00`H.'6Z__K``"&X`%K
M@.($8(;B!@"@X0'L_^N0-Y_E"""@X0`PC>6(%Y_EB#>?Y01`C>4`L*#A.^S_
MZPL`H.$'':#C<NO_ZP$`<.,8```*:$>?Y0``E.6LZ__K"Q"@X04M@.(#`*#C
M#NS_ZP``4.,<```*2!>?Y0`@E>4+,*#A``"1Y3P7G^79Z__K``"@XPA7G^4"
M&8WB+"&1Y0`PE>4#`%+AN0$`&H'<C>(TT(WB\(^]Z!GL_^L`,)#E$0!3X^+_
M_PKX%I_E`""5Y0`PC>4+,*#A``"1Y>P6G^7$Z__K``"@X^G__^H``)3EA^O_
MZU`QD.4/.@/B`0E3X]S__QH``)3E@>O_ZUAQD.5SZ__K``!7X=;__QH``)3E
M>^O_ZU`QD.6#.Z#A#@)3X]#__QH&`*#ANNO_ZS00C>(`H*#AB`:?Y:;[_^L`
M`%#CD`$`"@!`E>7EZ__K`!"@X00`H.&?_?_K`$!0XHD!``H$`*#A>^O_ZP,`
M4.,`8*#A"P``V@0`0.(``(3@1!:?Y=WK_^L``%#C!0``&@0`5N,W`0`*!F"$
MX`4P5N4O`%/C,P$`"KW^_^L`$%#B!```&@0`H.%VZ__K`%!0XB!0C>4Q```:
M`!:?Y0`&G^7-^__KI>O_Z_A5G^7X%9_E!%"-Y0L@H.'$-9_E`$"@XP``C>4*
M`*#AR>O_ZPP``.K$Z__K`#"0Y1$`4^,-```:ENO_ZP%`A.+`%9_E,`"-Z0L@
MH.&(-9_E``"-Y0H`H.&[Z__K"@"@X0<=H./RZO_K`0!PX^W__PH+`*#A)^O_
MZPH0H.%`!9_EJ_O_ZPH`H.&L_O_K"@"@X8;__^H`<*#A!/__ZJ?^_^L$`*#A
MF>O_ZX#__^I8=9_E#0"@XP'__^H"0*#C`##@XQ$@X.,`0(WE6NO_ZTL?C>(@
M`)WE!B"@XQ'K_^N!;(WB*#6?Y3!@AN(#,-;G``!3XP(``!HM,=WE0P!3XPP!
M``H`0*#C`$"-Y0`@H.,`,*#C(`"=Y4?K_^OT))_E`#"@X_`$G^4`$*#C\"O-
MX0`PH.,`(*#C^`O-X=S$G^7<9)_E($&-Y=@$G^781)_E\"W-X?@MS>&!/(WB
M`'"@XP!0H.,`$*#C,#"#XN"`C>+P;,WA^$S-X?P`@^$D@(WE**"-Y2RPC>4@
M`)WE2Q^-X@(IH./CZO_K`)!0XE<``-K)7Z#AB<&@X85AH.&I?H;A%'"-Y1#`
MC>70#<WAT&'-X0`@X.,`,*#C`&"6X`%PI^`"8`;@`W`'X`<`4>$&`%`!"4"@
MX=BMS>$!``":`:":X@"PJ^*D/J#AA<&#X:4.H.$8P(WE'`"-Y=@AS>$@$9WE
M\&W-X0*@FN`#L*O@``!1X_BMS>$S```*0%!AX@D`5>$)4*"A.`"!XJ@PC>(%
M(*#A``"#X$L?C>+4ZO_K("&=Y0(@A>!``%+C("&-Y<G__QI+;XWBJ`"-X@F0
M9>`%4(;@%.S_ZS\`6>,8``#:0*!)XH!@A>(J<Z#A0+"%X@=CAN!`0$OB"."@
MX0``E.4$$)3E"""4Y0PPE.4.P*#A$$"$X@L`5.$/`*SH#."@X?7__QJH`(WB
M0+"$XO[K_^L&`%OA[O__&@$@A^('DTK@`E.%X`40H.$D`)WE"2"@X:OJ_^L@
MD8WEH___ZDM?C>+<___J(`"=Y2B@G>4LL)WEM>K_Z]!`G>6!?(WB,'"'XJ0A
MH.$_(`+B`C"'X`$`@N(".4/B?Q#@XS@`4./84)WE4!!#Y3D`@N)D``#*J!"-
MX@``@>`W(&+B`!"@XUWJ_^LE?*#AN&*?Y1AQS>6!?(WB,'"'XB7HH.$EQ*#A
M)!R@X20HH.$D-*#AJ`"-XAM1S>4?0<WE&>'-Y1K!S>4<$<WE'2'-Y1XQS>7'
MZ__K!N"7YWQ"G^6PP)WE+BR@X;@`G>4$(,?G:^#-Y2Y(H.$NY*#A:N#-Y2SL
MH.'`$)WE;\#-Y6S@S>4LZ*#A+,2@X<@PG>5NP,WE(,R@X7,`S>5PP,WE(,B@
MX2`$H.%QP,WE<@#-Y2',H.$A"*#A=Q#-Y7LPS>4A%*#A=,#-Y74`S>4CS*#A
M(PB@X2,TH.%I0,WE:%"-XGQ`C>*D8(WB;>#-Y780S>5XP,WE>0#-Y7HPS>4`
M``#J`2#UY00`H.%@$9_E`D"$XK?J_^L&`%3A^/__&H0QG^5\((WB`,"@XPP`
MC>@*`*#AH!&?Y0L@H.%$,9_EI,#-Y:OJ_^OS_O_J!%"5Y0``5>/(_O\*!0"@
MX3/J_^L#`%#CQ/[_F@0`0.(``(7@:!&?Y9;J_^L``%#C!4"@`;W^_^JHP(WB
M``",X#\@8N(`$*#C^.G_ZZ@`C>)SZ__K`#"@X^`PC>7D,(WEZ#"-Y>PPC>7P
M,(WE]#"-Y?@PC>7\,(WE`#&-Y00QC>4(,8WE##&-Y1`QC>44,8WEB/__ZBXQ
MW>5!`%/C[_[_&B\QW>5#`%/C[/[_&C`QW>5(`%/CZ?[_&C$QW>5%`%/CYO[_
M&@`PX.,`0(WE(`"=Y3D@X.,OZO_K2Q^-XB``G>4I(*#CYNG_ZW`PG^5+?XWB
M!#"-Y0!PC>4*`*#AC!"?Y0L@H.$P,)_E9^K_ZZ_^_^HFZO_K`$"5Y7/^_^JT
M]P``H-D!`%#X``!L^0``('___PA___^`^0``=/D``'CX``"8V0$`J-D!``CZ
M``"(^0``5/L``,3Y``!@^0``P/@```#[``#D^0``]/D``&3Y``#\?___B:O-
M[_[<NIAX?___=E0R$`$C16?PX=+#.'___]3Y``#,^0``\$\MZ0S03>)D@Y_E
M``"8Y;CI_^L!,*#C!!"-XF$PP.50`Y_EZ/G_ZP``4.,"```*`##0Y3$`4^.+
M```*IOS_ZP``F.6KZ?_K+!.?Y0$@H.,+,*#CC.G_ZR!CG^4``%#C+@``"A`@
MD.7T/Q;E`0!3XQB0DN4I``#:]**?Y0!0H.,!0*#C"0``ZA`0DN4+`*#A%NK_
MZ_0_%N4``%#C'```&@%`A.($`%/A`5"%XA@``-H``)CEC^G_ZPD0H.$%(*#A
M`#"@X[+I_^L`<%#B#P``"@`@E^6H,I_E\!\6Y0@`DN4#,`#@`0M3XP2QD>?E
M__\*``":Y7_I_^L`$)?E`""@XP(PH.,(ZO_K`!"@X=[__^KT/Q;E`2!#X@4`
M4N%````*``"8Y7/I_^M8$I_E`2"@XP0PH.-4Z?_K-%*?Y0!`4.(*```*``"5
MY6KI_^L0,)3E-"*?Y0`0D^51Z?_K$#"4Y0`PD^4(,)/E`043XS@``!H``)CE
M7^G_ZQ`2G^4!(*#C!#"@XT#I_^OD09_E`%!0X@H```KX`9_E!!"-XHKY_^L`
M<%#B``"4Y5$```I1Z?_K$#"5Y0<@H.$`$)/E..G_ZP``F.5+Z?_K`$"@XZ"1
MG^6H<9_E84#`Y0``F.5%Z?_K!!"-XIQ%@.6H`9_E=OG_ZP``4.,`0*#A[`\&
MY1X```H'':#C_.C_ZQ$`4.,"```*`3"`X@$`4^-/``"*#-"-XO"/O>@!`%/C
MO/__V@%`H.,``)CE+^G_ZPD0H.$/Z?_K]#\6Y0%`A.($`%/A]___RK+__^H`
M`)7E)NG_ZQ`PE.4`$)/E8NG_Z\#__^H!,-#E``!3XW'__PIO___J\`\7Y=K\
M_^L``%#C[`\'Y3````H0()7EZ#"?Y0`@DN4($)+E`S`!X`$+4^,A```:$`"2
MY?!/%N4$$*#A_.C_ZQ`PE>6\()_E`$"4Y0#`D^4(,)SE`B`#X`$+4N,`8*#A
M"P``&A`@G.4$$*#A!C"@X:@`G^57Z?_K_^C_ZQ`@E>7P/Q;E``"2Y0`0D^6C
M^O_KJ___Z@``F.7WZ/_K$!"5Y0`@H.,",*#C`!"1Y7_I_^L`(*#AZ___Z@``
MF>7NZ/_K$!"5Y00@H.$",*#C`!"1Y7;I_^O6___J1`"?Y3WI_^OP'Q?E`#"@
MX00@H.$`$)'E,`"?Y3?I_^N8V0$`I/@``%SZ``"H^0$```0@`&3Z``!H^@``
M</H``%SX``!0^```F/H``'3Z``#`^@``.$`MZ0!0H.&"^__K`##0Y0!`H.$`
M`%/C!0``"@$@@.(O`%/C`D"@`0$PTN0``%/C^O__&BS\_^L``%#C.("]"```
M5>,X@+T(`##5Y0``4^,X@+T(!`"@X100G^7EZ/_K``!4X3B`O1@%`*#A.$"]
MZ+;Y_^J`^0``$$`MZ21`G^4``)3EL>C_ZP`0X..FZ/_K``"4Y:WH_^L,$)_E
M`""@XQ!`O>@SZ?_JF-D!`)#>```,,)_E`S"/X```4^,`,),5]NC_ZICB``#X
M12WI`'"@X4Q0G^5,8)_E!5"/X`9@C^`&8&7@`8"@X0*@H.%0Z/_K1F&PX?B%
MO0@$4$7B`$"@XP0PM>4'`*#A"!"@X0H@H.$!0(3B,_\OX08`5.'W__\:^(6]
MZ"#@```@X```'O\OX0A`+>D(@+WH`0`"`%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@`````#3[``!$^P``3/L``%3[``!<^P``</L````````L
M^P``3/@````````D^0``*/D``"#[``!4^```*/L````````,^P``%/L`````
M```E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`<&5R;'AS:2YC````26YT97)N86QS.CI005(Z.D)/3U0`````
M+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`
M````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/
M4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````
M4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-
M4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.`````%!!4E]#3$5!3CT``#$```!365-414T``"4P,G@`````)7,E
M<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L`````"YP87(`
M````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE
M=2TE=25S`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``$%21U8`````&````'!E<FP`````,````%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``
M55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````$Q$7TQ)
M0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!
M4EE?4$%42````%-(3$E"7U!!5$@``",A+W5S<B]B:6XO<&5R;`IE=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A
M<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D
M=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE
M(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ
M5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E
M($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P
M9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P
M<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3
M;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D
M:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O
M;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@
M("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN
M('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L
M;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B
M>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O
M;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@
M("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@
M("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&
M25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@
M("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@
M(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*
M("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D
M(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO
M<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ
M<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]
M('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R
M7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD
M("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)0
M05)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@
M)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES
M("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'
M5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*
M(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF
M:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC
M('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L
M97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@
M='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I
M.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2
M+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@
M96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES
M=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@
M("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[
M"B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@
M("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E
M>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O
M=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@
M;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE
M(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@
M("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E
M;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U
M9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@
M("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@
M)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@
M0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@
M("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@
M("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@
M("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@
M("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@
M?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![
M>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S
M(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A
M9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@
M;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@
M("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@
M("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E
M)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT
M('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[
M"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U
M=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A
M<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A
M;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF
M>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@
M(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?
M05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R
M;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P
M(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I
M<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A
M9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@
M("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@
M("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@
M979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?
M87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@
M("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@
M)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@
M>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@
M("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@
M("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@
M("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*
M(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/
M=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E
M9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@
M;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@
M("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R
M)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@
M("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@
M("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@
M('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@
M>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I
M('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P
M87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@
M:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P
M-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I
M92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D
M871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@
M,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H
M)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@
M("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@
M?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H
M)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@
M("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI
M=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@
M(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@
M;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$
M4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE
M("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@
M("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*
M("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN
M875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@
M(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P
M(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T
M:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E
M;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@
M;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D
M9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK
M*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*
M("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@
M("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D
M:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@
M(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@
M:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@
M('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N
M=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@
M("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,
M13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@
M("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@
M("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@
M('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!0
M05(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ
M4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B
M*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M
M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@
M("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B
M7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L
M("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R
M92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA
M;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET
M(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@
M("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@
M("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@
M("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@
M("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@
M("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@
M("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@
M("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*
M(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U
M<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L
M:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;
M('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H
M('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,
M;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC
M=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@
M("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@
M<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R
M97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R
M97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E
M<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4
M:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK
M=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P
M5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"![
M"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@
M("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@
M("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R
M;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W
M;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*("`@("`@("!M
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,
M14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*
M("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@
M("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E
M860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#([
M"B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@
M("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@
M("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7
M;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS
M.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@
M("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X
M="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@
M)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@
M+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M
M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F
M:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D
M9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H
M*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U
M8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@
M("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\
M?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@
M('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[
M4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^
M(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D
M<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]
M"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@
M("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@
M("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%
M*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R
M971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,
M14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@
M("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?
M8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*
M("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U
M:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B
M0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B([
M"B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*
M("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*
M<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q
M*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P
M<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*
M"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$
M7U\*`+Q&_W\!`````````.B>``#`G@````````$````!`````0```-<!```!
M````&`(```$````B`@```0```'$"```!````I0,```$```#+`P``#````&R8
M```-````:/<``!D````XUP$`&P````0````:````/-<!`!P````$````!```
M`)2!``#U_O]OW(0```4```"(CP``!@```)B(```*````2P4```L````0````
M%0`````````#````9-@!``(````H`@``%````!$````7````1)8``!$````4
ME@``$@```#`````3````"````/[__V^TE0``____;P,```#P__]OU)0`````
M````````````````````````````````````````````````````````````
M`$37`0```````````'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```
M>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!X
MF```>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8
M``!XF```>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```>)@`
M`'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```
M>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!XF```>)@``'B8``!X
MF```>)@``'B8``!XF```>)@``````````````````/____]\^P``1T-#.B`H
M1&5B:6%N(#0N."XQ+3$P*W)P:3$I(#0N."XQ`$=#0SH@*$1E8FEA;B`T+C<N
M,RTT*W)P:3$I(#0N-RXS`$$P````865A8FD``28````%-@`&!@@!"0$*`A($
M$P$4`14!%P,8`1D!&@(;`QP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`
M````````````````````````````````````````````````````````"P``
M``$````"````-($``#0!```9```````````````!`````````!,````'````
M`@```%"!``!0`0``(```````````````!``````````A````!P````(```!P
M@0``<`$``"0```````````````0`````````.`````4````"````E($``)0!
M``!(`P``!@`````````$````!````#0```#V__]O`@```-R$``#<!```O`,`
M``8`````````!`````0````^````"P````(```"8B```F`@``/`&```'````
M`0````0````0````1@````,````"````B(\``(@/``!+!0`````````````!
M`````````$X```#___]O`@```-24``#4%```W@````8``````````@````(`
M``!;````_O__;P(```"TE0``M!4``&`````'`````P````0`````````:@``
M``D````"````%)8``!06```P````!@`````````$````"````',````)````
M`@```$26``!$%@``*`(```8````-````!`````@```!\`````0````8```!L
MF```;!@```P```````````````0`````````=P````$````&````>)@``'@8
M``!0`P`````````````$````!````((````!````!@```,B;``#(&P``H%L`
M````````````"`````````"(`````0````8```!H]P``:'<```@`````````
M``````0`````````C@````$````"````</<``'!W``"\7P`````````````$
M`````````)8````!``!P@@```"Q7`0`LUP``"`````X`````````!```````
M``"A`````0````(````T5P$`--<```0```````````````0`````````JP``
M``X````#````.-<!`#C7```$```````````````$`````````+<````/````
M`P```#S7`0`\UP``!```````````````!`````````##`````0````,```!`
MUP$`0-<```0```````````````0`````````R`````8````#````1-<!`$37
M```@`0``!P`````````$````"````-$````!`````P```&38`0!DV```)`$`
M````````````!`````0```#6`````0````,```"(V0$`B-D``!``````````
M``````0`````````W`````@````#````F-D!`)C9```L$``````````````(
M`````````.$````!````,`````````"8V0``0P```````````````0````$`
M``#J`````P``<```````````V]D``#$```````````````$``````````0``
M``,```````````````S:``#Z```````````````!``````````$```!XF```
M````````#0`$````B)@```````````T``0```(R8```````````-```D80`D
"9```
